%bcond tests 1
%bcond network_tests 0

Summary:        Microsoft Authentication Library (MSAL) for Python
Name:           python-msal
Version:        1.26.0
Release:    1%{?dist}

License:        MIT
URL:            https://github.com/AzureAD/microsoft-authentication-library-for-python
Source0:         %{url}/archive/%{version}/microsoft-authentication-library-for-python-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

%if %{with tests}
BuildRequires:  python3dist(pytest)
%endif

%global _description %{expand:
The Microsoft Authentication Library for Python enables applications to
integrate with the Microsoft identity platform. It allows you to sign in users
or apps with Microsoft identities (Azure AD, Microsoft Accounts and Azure AD
B2C accounts) and obtain tokens to call Microsoft APIs such as Microsoft Graph
or your own APIs registered with the Microsoft identity platform. It is built
using industry standard OAuth2 and OpenID Connect protocols.}

%description %{_description}


%package -n python3-msal
Summary:        %{summary}
%description -n python3-msal %{_description}


%package -n python3-msal+broker
Summary: Subpackage for python3-msal with extra broker dependencies
Requires: python3-msal

%description -n python3-msal+broker
This is the subpackage for python3-msal with extra broker dependencies.

%files -n python3-msal+broker -f %{_pyproject_ghost_distinfo}



%prep
%autosetup -n microsoft-authentication-library-for-python-%{version}

sed -r \
    -e 's/^\-e/# &/' \
    -e 's/^(pytest-benchmark|perf_baseline)\b/# &/' \
%if %{without network_tests}
    -e 's/^(python-dotenv)\b/# &/' \
%endif
    requirements.txt | tee requirements-filtered.txt


%generate_buildrequires
%pyproject_buildrequires -r requirements-filtered.txt


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files msal


%check
%if %{with tests}
%if %{without network_tests}
k="${k-}${k+ and }not TestClientApplicationAcquireTokenSilentErrorBehaviors"
k="${k-}${k+ and }not TestClientApplicationAcquireTokenSilentFociBehaviors"
k="${k-}${k+ and }not TestClientApplicationForAuthorityMigration"
k="${k-}${k+ and }not TestTelemetryMaintainingOfflineState"
k="${k-}${k+ and }not TestClientApplicationWillGroupAccounts"
k="${k-}${k+ and }not TestClientCredentialGrant"
k="${k-}${k+ and }not TestScopeDecoration"
k="${k-}${k+ and }not (TestAuthority and test_unknown_host_wont_pass_instance_discovery)"
k="${k-}${k+ and }not (TestAuthority and test_wellknown_host_and_tenant)"
k="${k-}${k+ and }not (TestAuthority and test_wellknown_host_and_tenant_using_new_authority_builder)"
k="${k-}${k+ and }not TestAuthorityInternalHelperUserRealmDiscovery"
k="${k-}${k+ and }not TestCcsRoutingInfoTestCase"
k="${k-}${k+ and }not TestApplicationForRefreshInBehaviors"
k="${k-}${k+ and }not TestTelemetryOnClientApplication"
k="${k-}${k+ and }not TestTelemetryOnPublicClientApplication"
k="${k-}${k+ and }not TestTelemetryOnConfidentialClientApplication"
ignore="${ignore-} --ignore=tests/test_cryptography.py"
ignore="${ignore-} --ignore=tests/test_e2e.py"
%else
k="${k-}${k+ and }not (SshCertTestCase and test_ssh_cert_for_user_should_work_with_any_account)"
k="${k-}${k+ and }not (CryptographyTestCase and test_should_be_run_with_latest_version_of_cryptography)"
%endif

ignore="${ignore-} --ignore=tests/test_benchmark.py"

%pytest --disable-warnings tests ${ignore-} -k "${k-}" -v

%else
%endif


%files -n python3-msal -f %{pyproject_files}
%doc README.md


%changelog
* Fri Jul 19 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.26.0-1
- initial build
